@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import UTC, datetime
 
 import xarray as xr
 from pydantic import validate_call
@@ -17,7 +17,7 @@ from jua.weather._types.forecast import ForecastData
 from jua.weather.conversions import timedelta_to_hours, to_datetime
 from jua.weather.models import Models
 from jua.weather.statistics import Statistics
-from jua.weather.variables import Variables, rename_to_ept2
+from jua.weather.variables import Variables, rename_variable
 
 logger = get_logger(__name__)
 
@@ -51,7 +51,7 @@ class Forecast:
         ... )
     """
 
-    _MAX_INIT_TIME_PAST_FOR_API_H = 36
+    _MIN_INIT_TIME_PAST_FOR_API = datetime(2025, 8, 15, 0, tzinfo=UTC)
     _MAX_POINT_FOR_API = 1000
 
     def __init__(self, client: JuaClient, model: Models):
@@ -77,6 +77,9 @@ class Forecast:
             Models.EPT1_5: self._v3_data_adapter,
             Models.EPT1_5_EARLY: self._v3_data_adapter,
         }
+        self._MODEL_DATA_AVAILABILITY = {
+            Models.EPT2: datetime(2024, 3, 31, 0, tzinfo=UTC),
+        }
 
     def is_global_data_available(self) -> bool:
         """Check if global data access is available for this model.
@@ -374,7 +377,10 @@ class Forecast:
         Returns:
             List of variable names formatted for API requests
         """
-        return [rename_to_ept2(v) for v in variables]
+        return [
+            rename_variable(v.name) if isinstance(v, Variables) else rename_variable(v)
+            for v in variables
+        ]
 
     def _dispatch_to_api(
         self,
@@ -528,15 +534,10 @@ class Forecast:
                 raise ValueError("No metadata found for model")
             init_time = metadata.init_time
 
-        init_time_dt = to_datetime(init_time)
-        # Make now timezone-aware if init_time is timezone-aware
-        now = (
-            datetime.now(init_time_dt.tzinfo) if init_time_dt.tzinfo else datetime.now()
-        )
-
-        if (
-            now - init_time_dt
-        ).total_seconds() > self._MAX_INIT_TIME_PAST_FOR_API_H * 3600:
+        init_time_dt = to_datetime(init_time).replace(tzinfo=UTC)
+        if init_time_dt < self._MODEL_DATA_AVAILABILITY.get(
+            self._model, self._MIN_INIT_TIME_PAST_FOR_API
+        ):
             return False
 
         if points is None and (latitude is None or longitude is None):
