@@ -21,7 +21,7 @@ class Models(str, Enum):
     EPT1_5_EARLY = "ept1_5_early"
     EPT2 = "ept2"
     EPT2_EARLY = "ept2_early"
-    EPT2_RR = "ept2-rr"
+    EPT2_RR = "ept2_rr"
     ECMWF_IFS_SINGLE = "ecmwf_ifs025_single"
     ECMWF_IFS_ENSEMBLE = "ecmwf_ifs025_ensemble"
     ECMWF_AIFS_SINGLE = "ecmwf_aifs025_single"
@@ -33,4 +33,4 @@ class Models(str, Enum):
     GFS_GRAPHCAST = "gfs_graphcast025"
     AURORA = "aurora"
     AIFS = "aifs"
-    EPT2_E = "ept2-e"
+    EPT2_E = "ept2_e"
